# UserIdentityUpdate

Updates a user's core identity information. This is typically done as part of a login process, though a user can update their own information at any time. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**spec** | [**UserIdentityUpdateSpec**](UserIdentityUpdateSpec.md) |  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


